@@ -37,11 +37,14 @@ class BELTableFormatter(FormatterBase):
             relations = [a for a in document.annotations if a.labelName == 'relation']
             for rel in relations:
                 props = rel.properties
+                journal = "Unknown"
+                if document.metadata is not None:
+                    journal = document.metadata.get('journal', 'Unknown')
                 props.update(
                     {'PubMedID': document.identifier,
                      'EvidenceSentence': document.text[rel.start:rel.end],
                      'PublicationTitle': document.title,
-                     'Journal': document.metadata.get('journal', '')
+                     'Journal': journal
                      }
                 )
                 series.append(props)
@@ -53,23 +56,25 @@ class BELTableFormatter(FormatterBase):
                 filename = f"{filepath.stem}.{parameters.format.value}"
             if parameters.format == OutputFormat.xlsx:
                 bio = io.BytesIO()
-                df.to_excel(bio, index=False,
-                            columns=['Subject', 'Subject.start', 'Subject.end', 'Subject.text', 'Relation',
-                                     'Object', 'Object.start', 'Object.end', 'Object.text', 'Score', 'PubMedID',
-                                     'EvidenceSentence',
-                                     'PublicationTitle',
-                                     'Journal'])
+                if not df.empty:
+                    df.to_excel(bio, index=False,
+                                columns=['Subject', 'Subject.start', 'Subject.end', 'Subject.text', 'Relation',
+                                         'Object', 'Object.start', 'Object.end', 'Object.text', 'Score', 'PubMedID',
+                                         'EvidenceSentence',
+                                         'PublicationTitle',
+                                         'Journal'])
                 resp = Response(content=bio.getvalue(),
                                 media_type="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
                 resp.headers["Content-Disposition"] = f"attachment; filename={filename}"
             elif parameters.format == OutputFormat.csv:
                 sio = io.StringIO()
-                df.to_csv(sio, index=False,
-                          columns=['Subject', 'Subject.start', 'Subject.end', 'Subject.text', 'Relation',
-                                   'Object', 'Object.start', 'Object.end', 'Object.text', 'Score', 'PubMedID',
-                                   'EvidenceSentence',
-                                   'PublicationTitle',
-                                   'Journal'])
+                if not df.empty:
+                    df.to_csv(sio, index=False,
+                              columns=['Subject', 'Subject.start', 'Subject.end', 'Subject.text', 'Relation',
+                                       'Object', 'Object.start', 'Object.end', 'Object.text', 'Score', 'PubMedID',
+                                       'EvidenceSentence',
+                                       'PublicationTitle',
+                                       'Journal'])
                 resp = Response(content=sio.getvalue(),
                                 media_type="text/csv")
                 resp.headers["Content-Disposition"] = f"attachment; filename={filename}"
